@@ -82,6 +82,7 @@ import com.openexchange.mobile.api.facade.connectors.impl.StubsConnector;
 import com.openexchange.mobile.api.facade.connectors.impl.ThreadReferencesConnector;
 import com.openexchange.mobile.api.facade.connectors.impl.ThreadedAllStubsConnector;
 import com.openexchange.mobile.api.facade.connectors.impl.UpdateAccountConnector;
+import com.openexchange.mobile.api.facade.connectors.impl.UpdateFolderConnector;
 import com.openexchange.mobile.api.facade.connectors.impl.UserConnector;
 import com.openexchange.mobile.api.facade.connectors.impl.ValidateAccountConnector;
 import com.openexchange.mobile.api.facade.connectors.impl.VersionConnector;
@@ -108,6 +109,8 @@ public interface ConnectorFactory {
 
     CreateFolderConnector getCreateFolderConnector(SessionData sessionData, String parentFolderId, String name);
 
+    UpdateFolderConnector getUpdateFolderConnector(SessionData sessionData, String folderId, String newParentFolderId, String newName);
+
     DeleteAccountConnector getDeleteAccountConnector(SessionData sessionData, String accountId);
 
     DeleteFolderConnector getDeleteFolderConnector(SessionData sessionData, String folderId);
