@@ -174,16 +174,17 @@ public class RequestUtil {
             throw ApiFacadeException.badRequest(ApiFacadeException.Code.MISSING_COOKIES, "Cookies missing");
         }
         String hostname = getHostHeader(request);
+        String xHostname = getXHostHeader(request);
         String userAgent = getUserAgent(request);
         String trackingId = getTrackingId(request);
         String contextId = getContextId(request);
         String userId = getUserId(request);
         HostConfiguration hostConfiguration = ConfigurationHelper.getConfiguration(request);
         checkUserAgent(userAgent, hostConfiguration);
-        return enhanceSessionData(request, hostConfiguration, hostname, userAgent, trackingId, contextId, userId, new SessionData(session, cookies));
+        return enhanceSessionData(request, hostConfiguration, hostname, xHostname, userAgent, trackingId, contextId, userId, new SessionData(session, cookies));
     }
 
-    public static SessionData enhanceSessionData(HttpServletRequest request, HostConfiguration configuration, String hostname, String userAgent, String trackingId, String contextId, String userId, SessionData sessionData) {
+    public static SessionData enhanceSessionData(HttpServletRequest request, HostConfiguration configuration, String hostname, String xHostname, String userAgent, String trackingId, String contextId, String userId, SessionData sessionData) {
         if (trackingId != null) {
             sessionData.setProperty(SessionData.PROPERTY_TRACKING_ID, trackingId);
         }
@@ -193,8 +194,13 @@ public class RequestUtil {
         if (userId != null) {
             sessionData.setProperty(SessionData.PROPERTY_USER_ID, userId);
         }
+        Map<String, String> customProperties = configuration.getCustomProperties();
+        if (customProperties.size() > 0) {
+            sessionData.getProperties().putAll(customProperties);
+        }
         return sessionData
                 .withHost(hostname)
+                .withXHost(xHostname)
                 .withForwardedFor(getForwardedForWithRemoteIp(request))
                 .withForwardedProto(getForwardedProto(request))
                 .withUserAgent(userAgent)
@@ -327,11 +333,11 @@ public class RequestUtil {
     }
 
     public String getHostHeader(HttpServletRequest request) {
-        String value = request.getHeader(HEADER_X_HOST);
-        if (value == null) {
-            value = request.getHeader(HEADER_HOST);
-        }
-        return value;
+        return request.getHeader(HEADER_HOST);
+    }
+
+    public String getXHostHeader(HttpServletRequest request) {
+        return request.getHeader(HEADER_X_HOST);
     }
 
     public String getLanguage(HttpServletRequest request) {
